@@ -11,8 +11,9 @@ HTTP_TUPLE = ('HTTP', 80)
 # Target group
 TARGET_GROUP_COLOR_TAG_NAME = 'Color'
 TARGET_GROUP_TYPE_TAG_NAME = 'Type'
-TARGET_GROUP_DEFAULT_TYPE = 'default'
-TARGET_GROUP_GATEWAY_TYPE = 'gateway'
+# Default type means 'api gateway'
+TARGET_GROUP_DEFAULT_TYPE = 'DEFAULT'
+TARGET_GROUP_MAINTENANCE_TYPE = 'MAINTENANCE'
 
 # ECR
 ECR_SERVICE_PREFIX = 'lcdp-'
