@@ -3,14 +3,24 @@ from . import constant as constant
 
 ecs_client = boto3.client('ecs')
 
+def get_services_from_cluster(cluster_name, max_results=100):
+    return ecs_client.list_services(
+        cluster=cluster_name,
+        maxResults=max_results
+    )
+
+def get_services_arn_from_query(q, cluster_name):
+    founded_services = []
+    services = get_services_from_cluster(cluster_name)
+    for service_arn in services['serviceArns']:
+        if q.upper() in service_arn.upper():
+            founded_services.append(service_arn)
+    return founded_services
+
 # Récupère les arn de tous les services ecs d'un cluster pour une couleur donnée
 def get_services_arn_for_color(color, cluster_name):
     colored_services = []
-    services = ecs_client.list_services(
-        cluster=cluster_name,
-        # TODO: Review if one day we got more than 100 ecs services !
-        maxResults=100
-    )
+    services = get_services_from_cluster(cluster_name)
     for service_arn in services['serviceArns']:
         if color in service_arn.upper():
             colored_services.append(service_arn)
